@@ -1,9 +1,10 @@
 from upload_py import *
+import os
 
 #anonfiles
 print("Anonfiles:")
 file = anonfiles()
-file.upload(f"bootlogo.bmp")
+file.upload(f"{os.getcwd()}/file.txt")
 file.url_short()
 file.url_full()
 file.metadata()
@@ -12,7 +13,7 @@ print("")
 #starfiles
 print("starfiles:")
 file2 = starfiles()
-file2.upload(f"bootlogo.bmp")
+file2.upload(f"{os.getcwd()}/file.txt")
 file2.url_file()
 file2.url_file_direct()
 file2.url_ipa_install()
@@ -22,12 +23,12 @@ print("")
 #FilePipe
 print("FilePipe:")
 file3 = filepipe()
-file3.upload(f"bootlogo.bmp")
+file3.upload(f"{os.getcwd()}/file.txt")
 file3.url_file()
 print("")
 
 #FilePipe
 print("File.io:")
 file3 = fileio()
-file3.upload(f"bootlogo.bmp")
+file3.upload(f"{os.getcwd()}/file.txt")
 file3.url_file()
